==> react-bootstrap-0.4.0.tgz: package/es/components/List/Item.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { forwardRef } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import colors from '../../utils/colors';

import Button from '../Button';
import Icon from '../Icon';

var Item = forwardRef(function (_ref, ref) {
  var _cn;

  var Tag = _ref.tag,
      color = _ref.color,
      active = _ref.active,
      clickable = _ref.clickable,
      disabled = _ref.disabled,
      onClick = _ref.onClick,
      onToggle = _ref.onToggle,
      toggleIconName = _ref.toggleIconName,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['tag', 'color', 'active', 'clickable', 'disabled', 'onClick', 'onToggle', 'toggleIconName', 'children']);

  return React.createElement(
    Tag,
    _extends({
      ref: ref
    }, typeof onClick === 'function' ? { role: 'presentation', onClick: onClick } : {}, props, {
      className: cn('list-group-item', (_cn = {}, _cn['list-group-item-' + color] = color, _cn['list-group-item-action'] = typeof onClick === 'function' || clickable, _cn.toggled = typeof onToggle === 'function', _cn.active = active, _cn.disabled = disabled, _cn), props.className)
    }),
    typeof onToggle === 'function' ? React.createElement(
      Button,
      {
        color: active ? 'primary' : 'link',
        disabled: disabled,
        className: 'list-group-item-toggle',
        onClick: onToggle
      },
      React.createElement(Icon, { name: toggleIconName })
    ) : null,
    children
  );
});

Item.displayName = 'List.Item';

Item.propTypes = {
  active: PropTypes.bool,
  children: PropTypes.node,
  className: PropTypes.string,
  clickable: PropTypes.bool,
  color: PropTypes.oneOf(colors),
  disabled: PropTypes.bool,
  onClick: PropTypes.func,
  onToggle: PropTypes.func,
  tag: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  toggleIconName: PropTypes.string
};

Item.defaultProps = {
  active: false,
  children: null,
  className: undefined,
  clickable: false,
  color: undefined,
  disabled: false,
  onClick: null,
  onToggle: null,
  tag: 'li',
  toggleIconName: 'plus'
};

export default Item;

==> react-bootstrap-0.4.2.tgz: package/es/components/List/Item.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { forwardRef } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import colors from '../../utils/colors';

import Button from '../Button';
import Icon from '../Icon';

var Item = forwardRef(function (_ref, ref) {
  var _cn;

  var Tag = _ref.tag,
      color = _ref.color,
      active = _ref.active,
      clickable = _ref.clickable,
      disabled = _ref.disabled,
      onClick = _ref.onClick,
      onToggle = _ref.onToggle,
      toggleIconName = _ref.toggleIconName,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['tag', 'color', 'active', 'clickable', 'disabled', 'onClick', 'onToggle', 'toggleIconName', 'children']);

  return React.createElement(
    Tag,
    _extends({
      ref: ref
    }, typeof onClick === 'function' ? { role: 'presentation', onClick: onClick } : {}, props, {
      className: cn('list-group-item', (_cn = {}, _cn['list-group-item-' + color] = color, _cn['list-group-item-action'] = typeof onClick === 'function' || clickable, _cn.toggled = typeof onToggle === 'function', _cn.active = active, _cn.disabled = disabled, _cn), props.className)
    }),
    typeof onToggle === 'function' ? React.createElement(
      Button,
      {
        color: active ? 'primary' : 'link',
        disabled: disabled,
        className: 'list-group-item-toggle',
        onClick: onToggle
      },
      React.createElement(Icon, { name: toggleIconName })
    ) : null,
    children
  );
});

Item.displayName = 'List.Item';

Item.propTypes = {
  active: PropTypes.bool,
  children: PropTypes.node,
  className: PropTypes.string,
  clickable: PropTypes.bool,
  color: PropTypes.oneOf(colors),
  disabled: PropTypes.bool,
  onClick: PropTypes.func,
  onToggle: PropTypes.func,
  tag: PropTypes.oneOfType([PropTypes.elementType, PropTypes.func, PropTypes.string]),
  toggleIconName: PropTypes.string
};

Item.defaultProps = {
  active: false,
  children: null,
  className: undefined,
  clickable: false,
  color: undefined,
  disabled: false,
  onClick: null,
  onToggle: null,
  tag: 'li',
  toggleIconName: 'plus'
};

export default Item;
